pub struct StaticResponseCode(/* private fields */);Expand description
Responder that always responds with the given status code
Implementations
Sourceimpl StaticResponseCode
impl StaticResponseCode
Sourcepub fn new(status: StatusCode) -> Self
pub fn new(status: StatusCode) -> Self
Creates responder that always responds with the given status code
Sourcepub fn server_error() -> Self
pub fn server_error() -> Self
Creates responder that always responds with 500 Internal Server Error
Sourcepub fn too_many_requests() -> Self
pub fn too_many_requests() -> Self
Creates responder that always responds with 429 Too Many Requests