pub struct ServedRepositoryBuilder { /* private fields */ }Expand description
A builder to construct a test repository server.
Implementations
Sourceimpl ServedRepositoryBuilder
impl ServedRepositoryBuilder
Sourcepub fn response_overrider(self, responder: impl HttpResponder) -> Self
pub fn response_overrider(self, responder: impl HttpResponder) -> Self
Override how the ServedRepositoryBuilder responds to requests.
Requests are passed through responders in the order in which the responders are added to this builder.
Sourcepub fn use_https_domain(self, domain: Domain) -> Self
pub fn use_https_domain(self, domain: Domain) -> Self
Serve the repository over https via a domain known by test certificates and keys.
Sourcepub fn bind_to_addr(self, addr: impl Into<IpAddr>) -> Self
pub fn bind_to_addr(self, addr: impl Into<IpAddr>) -> Self
Bind the tcp listener to the provided ip address. Binds to Ipv6Addr::UNSPECIFIED by default.
Sourcepub fn bind_to_port(self, port: u16) -> Self
pub fn bind_to_port(self, port: u16) -> Self
Bind the tcp listener to the provided port. Binds to 0 (allowing system to select a port) by default.
Sourcepub fn start(self) -> Result<ServedRepository, Error>
pub fn start(self) -> Result<ServedRepository, Error>
Spawn the server on the current executor, returning a handle to manage the server.