pub struct FakeUpdatePackage { /* private fields */ }Expand description
A fake update_package::UpdatePackage backed by a temp dir.
Implementations
Sourceimpl FakeUpdatePackage
impl FakeUpdatePackage
Methods from Deref<Target = UpdatePackage>
Sourcepub async fn verify_name(&self) -> Result<(), VerifyNameError>
pub async fn verify_name(&self) -> Result<(), VerifyNameError>
Verifies that the package’s name/variant is “update/0”.
Sourcepub async fn images_metadata(
&self,
) -> Result<ImagesMetadata, ImagePackagesError>
pub async fn images_metadata( &self, ) -> Result<ImagesMetadata, ImagePackagesError>
Loads the image packages manifest, or determines that it is not present.
Sourcepub async fn verify_board(&self, contents: &str) -> Result<(), VerifyBoardError>
pub async fn verify_board(&self, contents: &str) -> Result<(), VerifyBoardError>
Verifies the board file has the given contents.
Sourcepub async fn update_mode(
&self,
) -> Result<Option<UpdateMode>, ParseUpdateModeError>
pub async fn update_mode( &self, ) -> Result<Option<UpdateMode>, ParseUpdateModeError>
Parses the update-mode file to obtain update mode. Returns Ok(None) if the update-mode
file is not present in the update package.
Sourcepub async fn packages(
&self,
) -> Result<Vec<FuchsiaPkgPinnedAbsolutePackageUrl>, ParsePackageError>
pub async fn packages( &self, ) -> Result<Vec<FuchsiaPkgPinnedAbsolutePackageUrl>, ParsePackageError>
Returns the list of package urls that go in the universe of this update package.
Sourcepub async fn hash(
&self,
) -> Result<GenericDigest<FuchsiaMerkleMarker>, HashError>
pub async fn hash( &self, ) -> Result<GenericDigest<FuchsiaMerkleMarker>, HashError>
Returns the package hash of this update package.
Sourcepub async fn version(&self) -> Result<SystemVersion, ReadVersionError>
pub async fn version(&self) -> Result<SystemVersion, ReadVersionError>
Returns the version of this update package.