pub struct PackageBuilder { /* private fields */ }Expand description
A builder to simplify construction of Fuchsia packages.
Implementations
Sourceimpl PackageBuilder
impl PackageBuilder
Sourcepub fn new(name: impl Into<String>) -> Self
pub fn new(name: impl Into<String>) -> Self
Creates a new PackageBuilder.
Panics
Panics if either:
nameis an invalid package name.- Creating a tempdir fails.
Sourcepub fn new_with_abi_revision(
name: impl Into<String>,
abi_revision: AbiRevision,
) -> Self
pub fn new_with_abi_revision( name: impl Into<String>, abi_revision: AbiRevision, ) -> Self
Creates a new PackageBuilder, just like PackageBuilder::new(), but
allowing the caller to specify the ABI revision with which to stamp the
test package.
Sourcepub fn dir(self, path: impl Into<PathBuf>) -> PackageDir
pub fn dir(self, path: impl Into<PathBuf>) -> PackageDir
Create a subdirectory within the package.
Panics
Panics if the package contains a file entry at path or any of its ancestors.
Sourcepub fn add_resource_at(
self,
path: impl Into<PathBuf>,
contents: impl Read,
) -> Self
pub fn add_resource_at( self, path: impl Into<PathBuf>, contents: impl Read, ) -> Self
Adds the provided contents to the package at the given path.
Panics
Panics if either:
- The package already contains a file or directory at
path. - The package contains a file at any of
path’s ancestors.
Sourcepub fn add_subpackage(
self,
name: impl TryInto<RelativePackageUrl>,
subpackage: &Package,
) -> Self
pub fn add_subpackage( self, name: impl TryInto<RelativePackageUrl>, subpackage: &Package, ) -> Self
Adds the provided subpackage to the package with name name.
Panics
Panics if either:
nameis not a valid RelativePackageUrl- There is already a subpackage called
name
Sourcepub fn add_subpackage_by_hash(
self,
name: impl TryInto<RelativePackageUrl>,
hash: Hash,
) -> Self
pub fn add_subpackage_by_hash( self, name: impl TryInto<RelativePackageUrl>, hash: Hash, ) -> Self
Adds a subpackage with name name and hash hash to the package.
Because the blobs of the subpackage are not provided, the Package built from this
PackageBuilder will not have the subpackage blobs.
Panics
Panics if either:
nameis not a valid RelativePackageUrl- There is already a subpackage called
name