pub struct Repository { /* private fields */ }Expand description
A TUF repository generated by a RepositoryBuilder.
Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn iter_blobs(
&self,
) -> Result<impl Iterator<Item = Result<Hash, Error>>, Error>
pub fn iter_blobs( &self, ) -> Result<impl Iterator<Item = Result<Hash, Error>>, Error>
Returns an iterator over all blobs contained in this repository.
Sourcepub fn list_blobs(&self) -> Result<BTreeSet<Hash>, Error>
pub fn list_blobs(&self) -> Result<BTreeSet<Hash>, Error>
Returns a set of all blobs contained in this repository.
Sourcepub fn purge_blobs(&self, blobs: impl Iterator<Item = Hash>)
pub fn purge_blobs(&self, blobs: impl Iterator<Item = Hash>)
Removes the specified from the repository.
Sourcepub fn read_blob(&self, merkle_root: &Hash) -> Result<Vec<u8>, Error>
pub fn read_blob(&self, merkle_root: &Hash) -> Result<Vec<u8>, Error>
Reads the contents of requested blob from the repository.
Sourcepub fn read_delivery_blob(
&self,
delivery_blob_type: u32,
merkle_root: &Hash,
) -> Result<Vec<u8>, Error>
pub fn read_delivery_blob( &self, delivery_blob_type: u32, merkle_root: &Hash, ) -> Result<Vec<u8>, Error>
Reads the contents of requested delivery blob from the repository.
Sourcepub fn write_blob(
&self,
merkle_root: &Hash,
blob: &[u8],
) -> Result<usize, Error>
pub fn write_blob( &self, merkle_root: &Hash, blob: &[u8], ) -> Result<usize, Error>
Writes a blob with the given merkle and data (which may not match), into the repository’s blobs directory, without any compression.
Sourcepub fn overwrite_uncompressed_delivery_blob(
&self,
merkle_root: &Hash,
) -> Result<usize, Error>
pub fn overwrite_uncompressed_delivery_blob( &self, merkle_root: &Hash, ) -> Result<usize, Error>
Overwrites the delivery blob to uncompressed version from an uncompressed blob that is already in the repository, returns the size of the delivery blob.
Sourcepub fn iter_packages(
&self,
) -> Result<impl Iterator<Item = Result<PackageEntry, Error>>, Error>
pub fn iter_packages( &self, ) -> Result<impl Iterator<Item = Result<PackageEntry, Error>>, Error>
Returns an iterator over all packages contained in this repository.
Sourcepub fn list_packages(&self) -> Result<Vec<PackageEntry>, Error>
pub fn list_packages(&self) -> Result<Vec<PackageEntry>, Error>
Returns a sorted vector of all packages contained in this repository.
Sourcepub fn make_repo_config_builder(
&self,
url: RepositoryUrl,
) -> RepositoryConfigBuilder
pub fn make_repo_config_builder( &self, url: RepositoryUrl, ) -> RepositoryConfigBuilder
Generate a RepositoryConfigBuilder suitable for configuring a
package resolver to use this repository when it is served at the given
URL.
Sourcepub fn make_repo_config(
&self,
url: RepositoryUrl,
mirror_config: Option<MirrorConfig>,
use_local_mirror: bool,
) -> RepositoryConfig
pub fn make_repo_config( &self, url: RepositoryUrl, mirror_config: Option<MirrorConfig>, use_local_mirror: bool, ) -> RepositoryConfig
Generate a RepositoryConfig suitable for configuring a package resolver to use this
repository when it is served at the given URL.
Sourcepub fn root_keys(&self) -> BTreeSet<RepositoryKey>
pub fn root_keys(&self) -> BTreeSet<RepositoryKey>
Get the root keys used by this repository.
Sourcepub fn server(self: Arc<Self>) -> ServedRepositoryBuilder
pub fn server(self: Arc<Self>) -> ServedRepositoryBuilder
Serves the repository over HTTP using hyper.