SystemImageBuilder

Struct SystemImageBuilder 

pub struct SystemImageBuilder { /* private fields */ }
Builds a system_image package.

Implementations

Source

impl SystemImageBuilder

pub fn new() -> Self

Returns an empty SystemImageBuilder configured with no static or cache package.

pub fn static_package(self, path: PackagePath, hash: Hash) -> Self

Appends the given path and hash to the static packages manifest.

pub fn static_packages(self, static_packages: &[&Package]) -> Self

Use the supplied static_packages with the system image. Call at most once and not after calling Self::static_package.

pub fn cache_package(self, path: PackagePath, hash: Hash) -> Self

Appends the given path and hash to the cache packages manifest, creating the manifest if it was not already staged to be added to the package.

pub fn cache_packages(self, cache_packages: &[&Package]) -> Self

Use the supplied cache_packages with the system image. Call at most once and not after calling Self::cache_package.

pub fn anchored_package( self, package_set_type: AnchoredPackageSetType, path: PackagePath, hash: Hash, ) -> Self

Appends the given package set type, path and hash to the anchored packages manifest, creating the manifest if it was not already staged to be added to the package.

pub fn pkgfs_disable_executability_restrictions(self) -> Self

Disable enforcement of executability restrictions for packages that are not base or allowlisted.

pub fn build(&self) -> impl Future<Output = Package>

Build the system_image package.